@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2021 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -219,9 +219,12 @@ class TestCaseOutputConfiguration:
     """The maximum number of statement in as test case (normal + assertion
     statements)"""
 
-    assertion_generation: AssertionGenerator = AssertionGenerator.SIMPLE
+    assertion_generation: AssertionGenerator = AssertionGenerator.MUTATION_ANALYSIS
     """The generator that shall be used for assertion generation."""
 
+    allow_stale_assertions: bool = False
+    """Allow assertion on things that did not change between statement executions."""
+
     mutation_strategy: MutationStrategy = MutationStrategy.FIRST_ORDER_MUTANTS
     """The strategy that shall be used for creating mutants in the mutation analysis
     assertion generation method."""
@@ -230,11 +233,6 @@ class TestCaseOutputConfiguration:
     """The order of the generated higher order mutants in the mutation analysis
     assertion generation method."""
 
-    generate_all_assertions: bool = True
-    """Should the mutation analysis approach to assertion generation also generate
-    assertions in cases where the states between non-mutated and mutated modules do
-    not differ?"""
-
     post_process: bool = True
     """Should the results be post processed? For example, truncate test cases after
     statements that raise an exception."""
