@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2021 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -9,7 +9,7 @@ from __future__ import annotations
 
 import ast
 import os
-from typing import TYPE_CHECKING, List, Union
+from typing import TYPE_CHECKING
 
 from pynguin.generation.export.abstractexporter import AbstractTestExporter
 
@@ -21,9 +21,7 @@ if TYPE_CHECKING:
 class PyTestExporter(AbstractTestExporter):
     """An exporter for PyTest-style test cases."""
 
-    def export_sequences(
-        self, path: Union[str, os.PathLike], test_cases: List[tc.TestCase]
-    ):
+    def export_sequences(self, path: str | os.PathLike, test_cases: list[tc.TestCase]):
         (
             module_aliases,
             common_modules,
