@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2021 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -19,7 +19,7 @@ from importlib import reload
 from math import inf
 from queue import Empty, Queue
 from types import CodeType, ModuleType
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Tuple, Type
+from typing import TYPE_CHECKING, Any, Callable
 
 import astor
 from bytecode import Compare
@@ -39,7 +39,7 @@ from pynguin.utils.type_utils import (
 )
 
 if TYPE_CHECKING:
-    import pynguin.assertion.statetrace as ot
+    import pynguin.assertion.assertion_trace as at
     import pynguin.testcase.statement as stmt
     import pynguin.testcase.testcase as tc
     import pynguin.testcase.variablereference as vr
@@ -57,13 +57,15 @@ class ExecutionContext:
             module_provider: The used module provider
         """
         self._module_provider = module_provider
-        self._local_namespace: Dict[str, Any] = {}
+        self._local_namespace: dict[str, Any] = {}
         self._variable_names = ns.NamingScope()
-        self._modules_aliases = ns.NamingScope(prefix="module")
-        self._global_namespace: Dict[str, ModuleType] = {}
+        self._module_aliases = ns.NamingScope(
+            prefix="module", new_name_callback=self._add_new_module_alias
+        )
+        self._global_namespace: dict[str, ModuleType] = {}
 
     @property
-    def local_namespace(self) -> Dict[str, Any]:
+    def local_namespace(self) -> dict[str, Any]:
         """The local namespace.
 
         Returns:
@@ -71,6 +73,15 @@ class ExecutionContext:
         """
         return self._local_namespace
 
+    @property
+    def module_aliases(self) -> ns.NamingScope:
+        """The module aliases
+
+        Returns:
+            A naming scope that maps the used modules to their alias.
+        """
+        return self._module_aliases
+
     def get_reference_value(self, reference: vr.Reference) -> Any:
         """Resolve the given reference in this execution context.
 
@@ -83,7 +94,7 @@ class ExecutionContext:
         Returns:
             The value that is resolved.
         """
-        root, *attrs = reference.get_names(self._variable_names, self._modules_aliases)
+        root, *attrs = reference.get_names(self._variable_names, self._module_aliases)
         if root in self._local_namespace:
             # Check local namespace first
             res = self._local_namespace[root]
@@ -92,13 +103,13 @@ class ExecutionContext:
             res = self._global_namespace[root]
         else:
             # Root name is not defined?
-            raise ValueError("Root not found in this context")
+            raise ValueError("Root not found in this context: " + root)
         for attr in attrs:
             res = getattr(res, attr)
         return res
 
     @property
-    def global_namespace(self) -> Dict[str, ModuleType]:
+    def global_namespace(self) -> dict[str, ModuleType]:
         """The global namespace.
 
         Returns:
@@ -118,17 +129,10 @@ class ExecutionContext:
         Returns:
             An executable ast node.
         """
-        modules_before = len(self._modules_aliases)
         visitor = stmt_to_ast.StatementToAstVisitor(
-            self._modules_aliases, self._variable_names
+            self._module_aliases, self._variable_names
         )
         statement.accept(visitor)
-        if modules_before != len(self._modules_aliases):
-            # new module added
-            # TODO(fk) cleaner solution?
-            self._global_namespace = self._create_global_namespace(
-                self._modules_aliases
-            )
         assert (
             len(visitor.ast_nodes) == 1
         ), "Expected statement to produce exactly one ast node"
@@ -147,24 +151,8 @@ class ExecutionContext:
         ast.fix_missing_locations(node)
         return ast.Module(body=[node], type_ignores=[])
 
-    def _create_global_namespace(
-        self,
-        modules_aliases: ns.NamingScope,
-    ) -> Dict[str, ModuleType]:
-        """Provides the required modules under the given aliases.
-
-        Args:
-            modules_aliases: The module aliases
-
-        Returns:
-            A dictionary of module aliases and the corresponding module
-        """
-        global_namespace: Dict[str, ModuleType] = {}
-        for required_module, module_name in modules_aliases:
-            global_namespace[module_name] = self._module_provider.get_module(
-                required_module
-            )
-        return global_namespace
+    def _add_new_module_alias(self, module_name: str, alias: str) -> None:
+        self._global_namespace[alias] = self._module_provider.get_module(module_name)
 
 
 class ExecutionObserver:
@@ -205,7 +193,7 @@ class ExecutionObserver:
         self,
         statement: stmt.Statement,
         exec_ctx: ExecutionContext,
-        exception: Optional[Exception] = None,
+        exception: Exception | None = None,
     ) -> None:
         """
         Called after a statement was executed.
@@ -221,9 +209,9 @@ class ExecutionResult:
     """Result of an execution."""
 
     def __init__(self, timeout: bool = False) -> None:
-        self._exceptions: Dict[int, Exception] = {}
-        self._output_traces: Dict[Type, ot.StateTrace] = {}
-        self._execution_trace: Optional[ExecutionTrace] = None
+        self._exceptions: dict[int, Exception] = {}
+        self._assertion_traces: dict[type, at.AssertionTrace] = {}
+        self._execution_trace: ExecutionTrace | None = None
         self._timeout = timeout
 
     @property
@@ -236,7 +224,7 @@ class ExecutionResult:
         return self._timeout
 
     @property
-    def exceptions(self) -> Dict[int, Exception]:
+    def exceptions(self) -> dict[int, Exception]:
         """Provide a map of statements indices that threw an exception.
 
         Returns:
@@ -245,14 +233,14 @@ class ExecutionResult:
         return self._exceptions
 
     @property
-    def output_traces(self) -> Dict[Type, ot.StateTrace]:
+    def assertion_traces(self) -> dict[type, at.AssertionTrace]:
         """Provides the gathered state traces.
 
         Returns:
             the gathered output traces.
 
         """
-        return self._output_traces
+        return self._assertion_traces
 
     @property
     def execution_trace(self) -> ExecutionTrace:
@@ -273,15 +261,15 @@ class ExecutionResult:
         """
         self._execution_trace = trace
 
-    def add_output_trace(self, trace_type: Type, trace: ot.StateTrace) -> None:
-        """Add the given trace to the recorded output traces.
+    def add_assertion_trace(self, trace_type: type, trace: at.AssertionTrace) -> None:
+        """Add the given trace to the recorded assertion traces.
 
         Args:
             trace_type: the type of trace.
             trace: the trace to store.
 
         """
-        self._output_traces[trace_type] = trace
+        self._assertion_traces[trace_type] = trace
 
     def has_test_exceptions(self) -> bool:
         """Returns true if any exceptions were thrown during the execution.
@@ -300,7 +288,7 @@ class ExecutionResult:
         """
         self._exceptions[stmt_idx] = ex
 
-    def get_first_position_of_thrown_exception(self) -> Optional[int]:
+    def get_first_position_of_thrown_exception(self) -> int | None:
         """Provide the index of the first thrown exception or None.
 
         Returns:
@@ -325,9 +313,9 @@ class ExecutionTrace:
     """Stores trace information about the execution."""
 
     executed_code_objects: OrderedSet[int] = field(default_factory=OrderedSet)
-    executed_predicates: Dict[int, int] = field(default_factory=dict)
-    true_distances: Dict[int, float] = field(default_factory=dict)
-    false_distances: Dict[int, float] = field(default_factory=dict)
+    executed_predicates: dict[int, int] = field(default_factory=dict)
+    true_distances: dict[int, float] = field(default_factory=dict)
+    false_distances: dict[int, float] = field(default_factory=dict)
 
     def merge(self, other: ExecutionTrace) -> None:
         """Merge the values from the other trace.
@@ -342,7 +330,7 @@ class ExecutionTrace:
         self._merge_min(self.false_distances, other.false_distances)
 
     @staticmethod
-    def _merge_min(target: Dict[int, float], source: Dict[int, float]) -> None:
+    def _merge_min(target: dict[int, float], source: dict[int, float]) -> None:
         """Merge source into target. Minimum value wins.
 
         Args:
@@ -361,7 +349,7 @@ class CodeObjectMetaData:
     code_object: CodeType
 
     # Id of the parent code object, if any
-    parent_code_object_id: Optional[int]
+    parent_code_object_id: int | None
 
     # CFG of this Code Object
     cfg: CFG
@@ -391,7 +379,7 @@ class KnownData:
     """
 
     # Maps all known ids of Code Objects to meta information
-    existing_code_objects: Dict[int, CodeObjectMetaData] = field(default_factory=dict)
+    existing_code_objects: dict[int, CodeObjectMetaData] = field(default_factory=dict)
 
     # Stores which of the existing code objects do not contain a branch, i.e.,
     # they do not contain a predicate. Every code object is initially seen as
@@ -399,7 +387,7 @@ class KnownData:
     branch_less_code_objects: OrderedSet[int] = field(default_factory=OrderedSet)
 
     # Maps all known ids of predicates to meta information
-    existing_predicates: Dict[int, PredicateMetaData] = field(default_factory=dict)
+    existing_predicates: dict[int, PredicateMetaData] = field(default_factory=dict)
 
 
 class ExecutionTracer:
@@ -412,7 +400,7 @@ class ExecutionTracer:
     # for certain op codes should be computed.
     # The returned tuple for each computation is (true distance, false distance).
     # pylint: disable=arguments-out-of-order
-    _DISTANCE_COMPUTATIONS: Dict[Compare, Callable[[Any, Any], Tuple[float, float]]] = {
+    _DISTANCE_COMPUTATIONS: dict[Compare, Callable[[Any, Any], tuple[float, float]]] = {
         Compare.EQ: lambda val1, val2: (
             _eq(val1, val2),
             _neq(val1, val2),
@@ -461,10 +449,10 @@ class ExecutionTracer:
         self._import_trace = ExecutionTrace()
         self._init_trace()
         self._enabled = True
-        self._current_thread_identifier: Optional[int] = None
+        self._current_thread_identifier: int | None = None
 
     @property
-    def current_thread_identifier(self) -> Optional[int]:
+    def current_thread_identifier(self) -> int | None:
         """Get the current thread identifier.
 
         Returns:
@@ -859,7 +847,7 @@ class ModuleProvider:
     """Class for providing modules."""
 
     def __init__(self):
-        self._mutated_module_aliases: Dict[str, ModuleType] = {}
+        self._mutated_module_aliases: dict[str, ModuleType] = {}
 
     def get_module(self, module_name: str) -> ModuleType:
         """
@@ -910,7 +898,7 @@ class TestCaseExecutor:
     _logger = logging.getLogger(__name__)
 
     def __init__(
-        self, tracer: ExecutionTracer, module_provider: Optional[ModuleProvider] = None
+        self, tracer: ExecutionTracer, module_provider: ModuleProvider | None = None
     ) -> None:
         """Create new test case executor.
 
@@ -922,7 +910,7 @@ class TestCaseExecutor:
             module_provider if module_provider is not None else ModuleProvider()
         )
         self._tracer = tracer
-        self._observers: List[ExecutionObserver] = []
+        self._observers: list[ExecutionObserver] = []
 
     @property
     def module_provider(self) -> ModuleProvider:
@@ -1044,7 +1032,7 @@ class TestCaseExecutor:
 
     def _execute_statement(
         self, statement: stmt.Statement, exec_ctx: ExecutionContext
-    ) -> Optional[Exception]:
+    ) -> Exception | None:
         ast_node = exec_ctx.executable_node_for(statement)
         if self._logger.isEnabledFor(logging.DEBUG):
             self._logger.debug("Executing %s", astor.to_source(ast_node))
@@ -1064,7 +1052,7 @@ class TestCaseExecutor:
         self,
         statement: stmt.Statement,
         exec_ctx: ExecutionContext,
-        exception: Optional[Exception],
+        exception: Exception | None,
     ):
         # See comments in _before_statement_execution
         if self.tracer.current_thread_identifier != threading.current_thread().ident:
